@@ -84,7 +84,7 @@ wireless_security_validate (WirelessSecurity *sec, GError **error)
 	g_assert (sec->validate);
 	result = (*(sec->validate)) (sec, error);
 	if (!result && error && !*error)
-		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Unknown error validating 802.1x security"));
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Unknown error validating 802.1X security"));
 	return result;
 }
 
@@ -172,6 +172,8 @@ wireless_security_init (gsize obj_size,
 	g_return_val_if_fail (ui_resource != NULL, NULL);
 	g_return_val_if_fail (ui_widget_name != NULL, NULL);
 
+	g_type_ensure (WIRELESS_TYPE_SECURITY);
+
 	sec = g_slice_alloc0 (obj_size);
 	g_assert (sec);
 
@@ -186,7 +188,7 @@ wireless_security_init (gsize obj_size,
 
 	sec->builder = gtk_builder_new ();
 	if (!gtk_builder_add_from_resource (sec->builder, ui_resource, &error)) {
-		g_warning ("Couldn't load UI builder file %s: %s",
+		g_warning ("Couldn't load UI builder resource %s: %s",
 		           ui_resource, error->message);
 		g_error_free (error);
 		wireless_security_unref (sec);
