@@ -264,7 +264,7 @@ get_authenticated_samba_devices_cb (GObject      *source_object,
   GtkWidget                 *widget;
   gboolean                   cancelled = FALSE;
   PpSamba                   *samba = (PpSamba *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   GList                     *iter;
 
   g_object_ref (samba);
@@ -324,8 +324,6 @@ get_authenticated_samba_devices_cb (GObject      *source_object,
           priv->samba_authenticated_searching = FALSE;
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 
   g_free (data->server_name);
@@ -526,7 +524,7 @@ pp_new_printer_dialog_init (PpNewPrinterDialog *dialog)
   PpNewPrinterDialogPrivate *priv;
   GtkStyleContext           *context;
   GtkWidget                 *widget;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   gchar                     *objects[] = { "dialog",
                                            "devices-liststore",
                                            "devices-model-filter",
@@ -545,7 +543,6 @@ pp_new_printer_dialog_init (PpNewPrinterDialog *dialog)
   if (builder_result == 0)
     {
       g_warning ("Could not load ui: %s", error->message);
-      g_error_free (error);
     }
 
   /* GCancellable for cancelling of async operations */
@@ -975,10 +972,10 @@ group_physical_devices_dbus_cb (GObject      *source_object,
                                 GAsyncResult *res,
                                 gpointer      user_data)
 {
-  GVariant   *output;
-  GError     *error = NULL;
-  gchar    ***result = NULL;
-  gint        i, j;
+  GVariant         *output;
+  g_autoptr(GError) error = NULL;
+  gchar          ***result = NULL;
+  gint              i, j;
 
   output = g_dbus_connection_call_finish (G_DBUS_CONNECTION (source_object),
                                           res,
@@ -1045,9 +1042,6 @@ DBus method \"GroupPhysicalDevices\" to group duplicates in device list.");
       error->domain != G_IO_ERROR ||
       error->code != G_IO_ERROR_CANCELLED)
     group_physical_devices_cb (result, user_data);
-
-  if (error)
-    g_error_free (error);
 }
 
 static void
@@ -1067,7 +1061,7 @@ get_cups_devices_cb (GList    *devices,
   const gchar                *device_class;
   GtkTreeIter                 iter;
   gboolean                    cont;
-  GError                     *error = NULL;
+  g_autoptr(GError)           error = NULL;
   GList                      *liter;
   gint                        length, i;
 
@@ -1183,7 +1177,6 @@ get_cups_devices_cb (GList    *devices,
               else
                 {
                   g_warning ("Failed to get system bus: %s", error->message);
-                  g_error_free (error);
                   group_physical_devices_cb (NULL, user_data);
                 }
 
@@ -1213,7 +1206,7 @@ get_snmp_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpNewPrinterDialogPrivate *priv;
   PpHost                    *host = (PpHost *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   PpDevicesList             *result;
 
   result = pp_host_get_snmp_devices_finish (host, res, &error);
@@ -1248,8 +1241,6 @@ get_snmp_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1261,7 +1252,7 @@ get_remote_cups_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpNewPrinterDialogPrivate *priv;
   PpHost                    *host = (PpHost *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   PpDevicesList             *result;
 
   result = pp_host_get_remote_cups_devices_finish (host, res, &error);
@@ -1296,8 +1287,6 @@ get_remote_cups_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1310,7 +1299,7 @@ get_samba_host_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpDevicesList             *result;
   PpSamba                   *samba = (PpSamba *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
 
   result = pp_samba_get_devices_finish (samba, res, &error);
   g_object_unref (source_object);
@@ -1344,8 +1333,6 @@ get_samba_host_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1358,7 +1345,7 @@ get_samba_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpDevicesList             *result;
   PpSamba                   *samba = (PpSamba *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
 
   result = pp_samba_get_devices_finish (samba, res, &error);
   g_object_unref (source_object);
@@ -1390,8 +1377,6 @@ get_samba_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1403,7 +1388,7 @@ get_jetdirect_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpNewPrinterDialogPrivate *priv;
   PpHost                    *host = (PpHost *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   PpDevicesList             *result;
 
   result = pp_host_get_jetdirect_devices_finish (host, res, &error);
@@ -1437,8 +1422,6 @@ get_jetdirect_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1450,7 +1433,7 @@ get_lpd_devices_cb (GObject      *source_object,
   PpNewPrinterDialog        *dialog;
   PpNewPrinterDialogPrivate *priv;
   PpHost                    *host = (PpHost *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
   PpDevicesList             *result;
 
   result = pp_host_get_lpd_devices_finish (host, res, &error);
@@ -1484,8 +1467,6 @@ get_lpd_devices_cb (GObject      *source_object,
 
           update_dialog_state (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -1950,7 +1931,7 @@ cups_get_dests_cb (GObject      *source_object,
   PpNewPrinterDialogPrivate *priv;
   PpCupsDests               *dests;
   PpCups                    *cups = (PpCups *) source_object;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
 
   dests = pp_cups_get_dests_finish (cups, res, &error);
   g_object_unref (source_object);
@@ -1976,8 +1957,6 @@ cups_get_dests_cb (GObject      *source_object,
 
           get_cups_devices (dialog);
         }
-
-      g_error_free (error);
     }
 }
 
@@ -2134,7 +2113,7 @@ printer_add_async_cb (GObject      *source_object,
   GtkResponseType            response_id = GTK_RESPONSE_OK;
   PpNewPrinter              *new_printer = (PpNewPrinter *) source_object;
   gboolean                   success;
-  GError                    *error = NULL;
+  g_autoptr(GError)          error = NULL;
 
   success = pp_new_printer_add_finish (new_printer, res, &error);
   g_object_unref (source_object);
@@ -2158,8 +2137,6 @@ printer_add_async_cb (GObject      *source_object,
 
           emit_response (dialog, response_id);
         }
-
-      g_error_free (error);
     }
 }
 
