@@ -23,6 +23,7 @@
 
 #include <string.h>
 #include <gio/gdesktopappinfo.h>
+#include <glib/gi18n.h>
 
 #include "cc-panel.h"
 #include "cc-panel-loader.h"
@@ -80,13 +81,8 @@ extern void cc_wacom_panel_static_init_func (void);
 
 #endif
 
-static struct {
-  const char *name;
-#ifndef CC_PANEL_LOADER_NO_GTYPES
-  GType (*get_type)(void);
-  CcPanelStaticInitFunc static_init_func;
-#endif
-} all_panels[] = {
+static CcPanelLoaderVtable default_panels[] =
+{
   PANEL_TYPE("background",       cc_background_panel_get_type,           NULL),
 #ifdef BUILD_BLUETOOTH
   PANEL_TYPE("bluetooth",        cc_bluetooth_panel_get_type,            NULL),
@@ -122,17 +118,12 @@ static struct {
 #endif
 };
 
-GList *
-cc_panel_loader_get_panels (void)
-{
-  GList *l = NULL;
-  guint i;
+/* Override for the panel vtable. When NULL, the default_panels will
+ * be used.
+ */
+static CcPanelLoaderVtable *panels_vtable = default_panels;
+static gsize panels_vtable_len = G_N_ELEMENTS (default_panels);
 
-  for (i = 0; i < G_N_ELEMENTS (all_panels); i++)
-    l = g_list_prepend (l, (gpointer) all_panels[i].name);
-
-  return g_list_reverse (l);
-}
 
 static int
 parse_categories (GDesktopAppInfo *app)
@@ -172,50 +163,6 @@ parse_categories (GDesktopAppInfo *app)
   return retval;
 }
 
-void
-cc_panel_loader_fill_model (CcShellModel *model)
-{
-  guint i;
-
-  for (i = 0; i < G_N_ELEMENTS (all_panels); i++)
-    {
-      g_autoptr (GDesktopAppInfo) app;
-      g_autofree gchar *desktop_name = NULL;
-      gint category;
-
-      desktop_name = g_strconcat ("gnome-", all_panels[i].name, "-panel.desktop", NULL);
-      app = g_desktop_app_info_new (desktop_name);
-
-      if (!app)
-        {
-          g_warning ("Ignoring broken panel %s (missing desktop file)", all_panels[i].name);
-          continue;
-        }
-
-      category = parse_categories (app);
-      if (G_UNLIKELY (category < 0))
-        continue;
-
-      /* Consult OnlyShowIn/NotShowIn for desktop environments */
-      if (!g_desktop_app_info_get_show_in (app, NULL))
-        continue;
-
-      cc_shell_model_add_item (model, category, G_APP_INFO (app), all_panels[i].name);
-    }
-
-  /* If there's an static init function, execute it after adding all panels to
-   * the model. This will allow the panels to show or hide themselves without
-   * having an instance running.
-   */
-#ifndef CC_PANEL_LOADER_NO_GTYPES
-  for (i = 0; i < G_N_ELEMENTS (all_panels); i++)
-    {
-      if (all_panels[i].static_init_func)
-        all_panels[i].static_init_func ();
-    }
-#endif
-}
-
 #ifndef CC_PANEL_LOADER_NO_GTYPES
 
 static GHashTable *panel_types;
@@ -229,13 +176,22 @@ ensure_panel_types (void)
     return;
 
   panel_types = g_hash_table_new (g_str_hash, g_str_equal);
-  for (i = 0; i < G_N_ELEMENTS (all_panels); i++)
-    g_hash_table_insert (panel_types, (char*)all_panels[i].name, all_panels[i].get_type);
+  for (i = 0; i < panels_vtable_len; i++)
+    g_hash_table_insert (panel_types, (char*)panels_vtable[i].name, panels_vtable[i].get_type);
 }
 
+/**
+ * cc_panel_loader_load_by_name:
+ * @shell: a #CcShell implementation
+ * @name: name of the panel
+ * @parameters: parameters passed to the new panel
+ *
+ * Creates a new instance of a #CcPanel from @name, and sets the
+ * @shell and @parameters properties at construction time.
+ */
 CcPanel *
 cc_panel_loader_load_by_name (CcShell     *shell,
-                              const char  *name,
+                              const gchar *name,
                               GVariant    *parameters)
 {
   GType (*get_type) (void);
@@ -243,7 +199,7 @@ cc_panel_loader_load_by_name (CcShell     *shell,
   ensure_panel_types ();
 
   get_type = g_hash_table_lookup (panel_types, name);
-  g_return_val_if_fail (get_type != NULL, NULL);
+  g_assert (get_type != NULL);
 
   return g_object_new (get_type (),
                        "shell", shell,
@@ -252,3 +208,98 @@ cc_panel_loader_load_by_name (CcShell     *shell,
 }
 
 #endif /* CC_PANEL_LOADER_NO_GTYPES */
+
+/**
+ * cc_panel_loader_fill_model:
+ * @model: a #CcShellModel
+ *
+ * Fills @model with information from the available panels. It
+ * iterates over the panel vtable, gathering the panel names,
+ * build the desktop filename from it, and retrieves additional
+ * information from it.
+ */
+void
+cc_panel_loader_fill_model (CcShellModel *model)
+{
+  guint i;
+
+  for (i = 0; i < panels_vtable_len; i++)
+    {
+      g_autoptr (GDesktopAppInfo) app;
+      g_autofree gchar *desktop_name = NULL;
+      gint category;
+
+      desktop_name = g_strconcat ("gnome-", panels_vtable[i].name, "-panel.desktop", NULL);
+      app = g_desktop_app_info_new (desktop_name);
+
+      if (!app)
+        {
+          g_warning ("Ignoring broken panel %s (missing desktop file)", panels_vtable[i].name);
+          continue;
+        }
+
+      category = parse_categories (app);
+      if (G_UNLIKELY (category < 0))
+        continue;
+
+      /* Consult OnlyShowIn/NotShowIn for desktop environments */
+      if (!g_desktop_app_info_get_show_in (app, NULL))
+        continue;
+
+      cc_shell_model_add_item (model, category, G_APP_INFO (app), panels_vtable[i].name);
+    }
+
+  /* If there's an static init function, execute it after adding all panels to
+   * the model. This will allow the panels to show or hide themselves without
+   * having an instance running.
+   */
+#ifndef CC_PANEL_LOADER_NO_GTYPES
+  for (i = 0; i < panels_vtable_len; i++)
+    {
+      if (panels_vtable[i].static_init_func)
+        panels_vtable[i].static_init_func ();
+    }
+#endif
+}
+
+/**
+ * cc_panel_loader_list_panels:
+ *
+ * Prints the list of panels from the current panel vtable,
+ * usually as response to running GNOME Settings with the
+ * '--list' command line argument.
+ */
+void
+cc_panel_loader_list_panels (void)
+{
+  guint i;
+
+  g_print ("%s\n", _("Available panels:"));
+
+  for (i = 0; i < panels_vtable_len; i++)
+    g_print ("\t%s\n", panels_vtable[i].name);
+
+}
+
+/**
+ * cc_panel_loader_override_vtable:
+ * @override_vtable: the new panel vtable
+ * @n_elements: number of items of @override_vtable
+ *
+ * Override the default panel vtable so that GNOME Settings loads
+ * a custom set of panels. Intended to be used by tests to inject
+ * panels that exercise specific interactions with CcWindow (e.g.
+ * header widgets, permissions, etc).
+ */
+void
+cc_panel_loader_override_vtable (CcPanelLoaderVtable *override_vtable,
+                                 gsize                n_elements)
+{
+  g_assert (override_vtable != NULL);
+  g_assert (n_elements > 0);
+
+  g_debug ("Overriding default panel vtable");
+
+  panels_vtable = override_vtable;
+  panels_vtable_len = n_elements;
+}
