@@ -64,7 +64,6 @@ struct _CcWindow
   GtkWidget  *search_button;
   GtkWidget  *search_bar;
   GtkWidget  *search_entry;
-  GtkWidget  *lock_button;
   GtkWidget  *development_warning_dialog;
   GtkWidget  *current_panel;
   char       *current_panel_id;
@@ -185,9 +184,6 @@ activate_panel (CcWindow          *self,
   cc_shell_set_active_panel (CC_SHELL (self), CC_PANEL (self->current_panel));
   gtk_widget_show (self->current_panel);
 
-  gtk_lock_button_set_permission (GTK_LOCK_BUTTON (self->lock_button),
-                                  cc_panel_get_permission (CC_PANEL (self->current_panel)));
-
   gtk_stack_add_named (GTK_STACK (self->stack), self->current_panel, id);
 
   /* switch to the new panel */
@@ -301,7 +297,7 @@ setup_model (CcWindow *shell)
       g_autofree gchar *name = NULL;
       g_autofree gchar *description = NULL;
       g_autofree gchar *id = NULL;
-      g_autofree GStrv keywords = NULL;
+      g_auto(GStrv) keywords = NULL;
       CcPanelVisibility visibility;
       const gchar *icon_name = NULL;
 
@@ -512,7 +508,7 @@ gdk_window_set_cb (GObject    *object,
                    CcWindow   *self)
 {
   GdkWindow *window;
-  gchar *str;
+  g_autofree gchar *str = NULL;
 
   if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
     return;
@@ -524,7 +520,6 @@ gdk_window_set_cb (GObject    *object,
 
   str = g_strdup_printf ("%u", (guint) GDK_WINDOW_XID (window));
   g_setenv ("GNOME_CONTROL_CENTER_XID", str, TRUE);
-  g_free (str);
 }
 
 static gboolean
@@ -616,7 +611,7 @@ split_decorations_cb (GtkSettings *settings,
   g_autofree gchar *layout = NULL;
   g_autofree gchar *layout_start = NULL;
   g_autofree gchar *layout_end = NULL;
-  g_autofree gchar **buttons;
+  g_auto(GStrv) buttons = NULL;
 
   g_object_get (settings, "gtk-decoration-layout", &layout, NULL);
 
@@ -837,7 +832,6 @@ cc_window_class_init (CcWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, CcWindow, header_box);
   gtk_widget_class_bind_template_child (widget_class, CcWindow, header_sizegroup);
   gtk_widget_class_bind_template_child (widget_class, CcWindow, list_scrolled);
-  gtk_widget_class_bind_template_child (widget_class, CcWindow, lock_button);
   gtk_widget_class_bind_template_child (widget_class, CcWindow, panel_headerbar);
   gtk_widget_class_bind_template_child (widget_class, CcWindow, panel_list);
   gtk_widget_class_bind_template_child (widget_class, CcWindow, previous_button);
